package com.anyway.favor.controller;

import com.anyway.favor.model.Favor;
import com.anyway.favor.model.FavorItem;
import com.anyway.favor.model.Person;
import com.anyway.favor.model.User;
import com.anyway.favor.service.FavorItemService;
import com.anyway.favor.service.FavorService;
import com.anyway.favor.service.PersonService;
import com.anyway.util.PageQuery;
import com.anyway.util.R;
import com.anyway.util.SessionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 人情控制器
 *
 * @author liuchuanwei
 * @date 2024-02-24
 */
@Controller
@RequestMapping("/favor")
public class FavorController {
    @Autowired
    private FavorService favorService;
    @Autowired
    private FavorItemService favorItemService;
    @Autowired
    private PersonService personService;

    /**
     * 跳转列表页面
     *
     * @param mv
     * @return
     */
    @RequestMapping("/toList")
    public ModelAndView toList(ModelAndView mv) {
        User currentUser = SessionUtils.currentUser();
        //人员列表
        Map<String, Object> map = new HashMap<>();
        map.put("relatedId", SessionUtils.currentUserId());
        List<Person> personList = personService.findByCondition(map);
        mv.addObject("personList", personList);
        mv.setViewName("/favor/list");
        return mv;
    }


    /**
     * 人情事件列表
     *
     * @param pageQuery
     * @return
     */
    @ResponseBody
    @RequestMapping("/listPage")
    public R listPage(@RequestBody PageQuery<Map<String, Object>> pageQuery) {
        User currentUser = SessionUtils.currentUser();
        Map<String, Object> mapCondition = pageQuery.getTerms();
        //查询和当前登录用户相关的人员
        mapCondition.put("relatedId", currentUser.getId());
        List<Favor> favorList = favorService.findPage(pageQuery);
        return R.page(favorList, pageQuery.getPage());
    }

    /**
     * 跳转新增页面
     *
     * @param mv
     * @return
     */
    @RequestMapping("/toAdd")
    public ModelAndView toAdd(ModelAndView mv, @RequestParam(required = false) Long personId, @RequestParam(required = false) String sourcePersonIds) {
        mv.setViewName("favor/add");
        //人员列表
        Map<String, Object> map = new HashMap<>();
        map.put("relatedId", SessionUtils.currentUserId());
        List<Person> personList = personService.findByCondition(map);
        mv.addObject("personList", personList);
        //送礼人员列表
        if (!StringUtils.isEmpty(sourcePersonIds)) {
            map.put("idList", Arrays.asList(sourcePersonIds.split(",")));
            List<Person> sourcePersonList = personService.findByCondition(map);
            mv.addObject("sourcePersonList", sourcePersonList);
        }
        Person person = personService.findById(personId != null ? personId : 1L);
        mv.addObject("person", person);
        return mv;
    }

    /**
     * 添加人情
     *
     * @param favor
     * @return
     */
    @ResponseBody
    @RequestMapping("/add")
    public R add(@RequestBody Favor favor) {
        User currentUser = SessionUtils.currentUser();
        favor.setCreateBy(currentUser.getId());
        favor.setModifyBy(currentUser.getId());
        return favorService.add(favor) ? R.ok() : R.fail("新增失败");
    }

    /**
     * 跳转编辑人情页面
     *
     * @return
     */
    @RequestMapping("/edit/{id}")
    public ModelAndView edit(@PathVariable Long id, ModelAndView mv) {
        mv.setViewName("favor/add");
        Favor favor = favorService.findById(id);
        List<FavorItem> favorItemList = favorItemService.findByFavorId(favor.getId());
        favor.setFavorItemList(favorItemList);
        mv.addObject("favor", favor);
        //人员列表
        List<Person> personList = personService.findAll();
        mv.addObject("personList", personList);
        return mv;
    }

    /**
     * 更新人情
     *
     * @param favor
     * @return
     */
    @ResponseBody
    @RequestMapping("/update")
    public R update(@RequestBody Favor favor) {
        User currentUser = SessionUtils.currentUser();
        favor.setModifyBy(currentUser.getId());
        return favorService.update(favor) ? R.ok() : R.fail("保存失败");
    }

    /**
     * 跳转人情详情页面
     *
     * @return
     */
    @RequestMapping("/detail/{id}")
    public ModelAndView detail(@PathVariable Long id, ModelAndView mv) {
        mv.setViewName("/favor/detail");
        Favor favor = favorService.findById(id);
        List<FavorItem> favorItemList = favorItemService.findByFavorId(favor.getId());
        favor.setFavorItemList(favorItemList);
        mv.addObject("favor", favor);
        //人员列表
        List<Person> personList = personService.findAll();
        mv.addObject("personList", personList);
        return mv;
    }

    /**
     * 删除
     *
     * @param id
     * @return
     */
    @RequestMapping("/delete/{id}")
    @ResponseBody
    public R delete(@PathVariable Long id) {
        boolean b = favorService.deleteById(id);
        return b ? R.ok() : R.fail("删除失败");
    }

}
