package com.anyway.favor.controller;

import com.anyway.favor.model.Person;
import com.anyway.favor.model.User;
import com.anyway.favor.service.PersonService;
import com.anyway.util.Couple;
import com.anyway.util.PageQuery;
import com.anyway.util.R;
import com.anyway.util.SessionUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 人员控制器
 *
 * @author liuchuanwei
 * @date 2024-02-20
 */
@Controller
@RequestMapping("/person")
public class PersonController {
    @Autowired
    private PersonService personService;

    /**
     * 跳转添加人员页面
     *
     * @return
     */
    @RequestMapping("/toAdd")
    public ModelAndView toAdd(ModelAndView mv) {
        User currentUser = SessionUtils.currentUser();
        Map<String, Object> mapCondition = new HashMap<>();
        mapCondition.put("relatedId", currentUser.getId());
        //母亲列表
        mapCondition.put("gender", "F");
        mapCondition.put("maritalStatus", "1");
        List<Person> motherPersonList = personService.findByCondition(mapCondition);
        mv.addObject("motherPersonOptionList", Couple.toList(motherPersonList, e -> e.getCallName() + "（" + e.getName() + "）", e -> String.valueOf(e.getId())));
        //父亲列表
        mapCondition.put("gender", "M");
        List<Person> fatherPersonList = personService.findByCondition(mapCondition);
        mv.addObject("fatherPersonOptionList", Couple.toList(fatherPersonList, e -> e.getCallName() + "（" + e.getName() + "）", e -> String.valueOf(e.getId())));
        //配偶列表
        mapCondition.put("gender", null);
        mapCondition.put("maritalStatus", null);
        mapCondition.put("emptyMate", true);
        mapCondition.put("sortName", "marital_status");
        mapCondition.put("sortOrder", "asc");
        List<Person> matePersonList = personService.findByCondition(mapCondition);
        mv.addObject("matePersonOptionList", Couple.toList(matePersonList, e -> e.getCallName() + "（" + e.getName() + "）", e -> String.valueOf(e.getId())));
        mv.setViewName("/person/edit");
        return mv;
    }

    /**
     * 添加人员
     *
     * @param person
     * @return
     */
    @ResponseBody
    @RequestMapping("/add")
    public R add(@RequestBody Person person) {
        User currentUser = SessionUtils.currentUser();
        person.setRelatedId(currentUser.getId());
        person.setCreateBy(currentUser.getId());
        person.setModifyBy(currentUser.getId());
        return personService.add(person) ? R.ok() : R.fail("新增失败");
    }

    /**
     * 跳转编辑人员页面
     *
     * @return
     */
    @RequestMapping("/edit/{id}")
    public ModelAndView edit(@PathVariable Long id) {
        ModelAndView mv = new ModelAndView();
        Person person = personService.findById(id);
        mv.addObject("person", person);
        mv.setViewName("/person/edit");

        User currentUser = SessionUtils.currentUser();
        Map<String, Object> mapCondition = new HashMap<>();
        mapCondition.put("relatedId", currentUser.getId());
        //母亲列表（女且已婚）
        mapCondition.put("gender", "F");
        mapCondition.put("maritalStatus", "1");
        List<Person> motherPersonList = personService.findByCondition(mapCondition);
        mv.addObject("motherPersonOptionList", Couple.toList(motherPersonList, e -> e.getCallName() + "（" + e.getName() + "）", e -> String.valueOf(e.getId())));
        //父亲列表（男且已婚）
        mapCondition.put("gender", "M");
        List<Person> fatherPersonList = personService.findByCondition(mapCondition);
        mv.addObject("fatherPersonOptionList", Couple.toList(fatherPersonList, e -> e.getCallName() + "（" + e.getName() + "）", e -> String.valueOf(e.getId())));
        //配偶列表（男/女且配偶为空且未婚）
        mapCondition.put("gender", "F".equals(person.getGender()) ? "M" : "F");
        mapCondition.put("emptyMate", true);
        mapCondition.put("maritalStatus", "0");
        List<Person> matePersonList = personService.findByCondition(mapCondition);
        mv.addObject("matePersonOptionList", Couple.toList(matePersonList, e -> e.getCallName() + "（" + e.getName() + "）", e -> String.valueOf(e.getId())));
        return mv;
    }
    /**
     * 更新人员
     *
     * @param person
     * @return
     */
    @ResponseBody
    @RequestMapping("/update")
    public R update(@RequestBody Person person) {
        User currentUser = SessionUtils.currentUser();
        person.setModifyBy(currentUser.getId());
        return personService.update(person) ? R.ok() : R.fail("保存失败");
    }

    /**
     * 跳转人员列表页面
     *
     * @return
     */
    @RequestMapping("/toList")
    public ModelAndView toList(@RequestParam Map<String, Object> mapCondition) {
        ModelAndView mv = new ModelAndView();
        //查询和当前登录用户相关的人员
        User currentUser = SessionUtils.currentUser();
        mapCondition.put("relatedId", currentUser.getId());
        List<Person> personList = personService.findByCondition(mapCondition);
        mv.addObject("familyPersonList", personList);
        mv.setViewName("/person/list");
        return mv;
    }

    /**
     * 人员列表
     *
     * @param pageQuery
     * @return
     */
    @ResponseBody
    @RequestMapping("/listPage")
    public R listPage(@RequestBody PageQuery<Map<String, Object>> pageQuery) {
        User currentUser = SessionUtils.currentUser();
        Map<String, Object> mapCondition = pageQuery.getTerms();
        //查询和当前登录用户相关的人员
        mapCondition.put("relatedId", currentUser.getId());
        List<Person> personList = personService.findPage(pageQuery);
        return R.page(personList, pageQuery.getPage());
    }

    /**
     * 人员列表选项
     *
     * @return
     */
    @ResponseBody
    @RequestMapping("/listOption")
    public List<Couple> listOption(Person person) {
        User currentUser = SessionUtils.currentUser();
        Map<String, Object> mapCondition = new HashMap<>();
        if (!StringUtils.isEmpty(person.getGender())) {
            mapCondition.put("gender", person.getGender());
        }
        if (person.getMaritalStatus() != null) {
            mapCondition.put("maritalStatus", person.getMaritalStatus());
        }
        mapCondition.put("relatedId", currentUser.getId());
        List<Person> personList = personService.findByCondition(mapCondition);
        List<Couple> coupleList = new ArrayList<>();
        for (Person p : personList) {
            coupleList.add(new Couple(p.getId().toString(), p.getCallName() + "（"+p.getName()+"）"));
        }
        return coupleList;
    }


    /**
     * 删除人员
     *
     * @param id
     * @return
     */
    @ResponseBody
    @RequestMapping("/del/{id}")
    public R del(@PathVariable Long id) {
        int c = personService.delete(id);
        return  c > 0? R.ok() : R.fail("删除失败");
    }
}
