package com.anyway.favor.service.impl;

import com.anyway.favor.mapper.FavorItemMapper;
import com.anyway.favor.mapper.FavorMapper;
import com.anyway.favor.model.Favor;
import com.anyway.favor.model.FavorItem;
import com.anyway.favor.service.FavorService;
import com.anyway.util.PageQuery;
import com.anyway.util.PageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Map;
/**
 * 人情业务实现类
 *
 * @author liuchuanwei
 * @date 2024-02-24
 */
@Service
public class FavorServiceImpl implements FavorService {
    @Autowired
    private FavorMapper favorMapper;
    @Autowired
    private FavorItemMapper favorItemMapper;

    @Override
    public List<Favor> findByCondition(Map<String, Object> map) {
        return favorMapper.findByCondition(map);
    }

    @Override
    public List<Favor> findPage(PageQuery<Map<String, Object>> pageQuery) {
        PageUtils.startPage(pageQuery);
        List<Favor> favorList = favorMapper.findByCondition(pageQuery.getTerms());
        PageUtils.setPageTotal(favorList, pageQuery);
        return favorList;
    }

    @Override
    public boolean add(Favor favor) {
        int r = favorMapper.add(favor);
        if (r > 0) {
            List<FavorItem> favorItemList = favor.getFavorItemList();
            for (FavorItem favorItem : favorItemList) {
                favorItem.setFavorId(favor.getId());
                favorItem.setOccurDate(favor.getOccurDate());
                favorItem.setCreateBy(favor.getCreateBy());
                favorItem.setModifyBy(favor.getModifyBy());
            }
            favorItemMapper.batchAdd(favorItemList);
        }
        return r > 0;
    }

    @Override
    public boolean update(Favor favor) {
        int r = favorMapper.update(favor);
        if (r > 0) {
            int i = favorItemMapper.deleteByFavorId(favor.getId());
            if (i > 0) {
                List<FavorItem> favorItemList = favor.getFavorItemList();
                for (FavorItem favorItem : favorItemList) {
                    favorItem.setFavorId(favor.getId());
                    favorItem.setOccurDate(favor.getOccurDate());
                    favorItem.setCreateBy(favor.getCreateBy());
                    favorItem.setModifyBy(favor.getModifyBy());
                }
                favorItemMapper.batchAdd(favorItemList);
            }
        }
        return r > 0;
    }

    @Override
    public Favor findById(Long id) {
        return favorMapper.findById(id);
    }

    @Override
    public boolean deleteById(Long id) {
        int i = favorMapper.deleteById(id);
        if (i>0) {
            favorItemMapper.deleteByFavorId(id);
        }
        return i>0;
    }
}
