package com.anyway.favor.service.impl;

import com.anyway.favor.mapper.PersonMapper;
import com.anyway.favor.model.Person;
import com.anyway.favor.service.PersonService;
import com.anyway.util.PageQuery;
import com.anyway.util.PageUtils;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 人员业务实现类
 *
 * @author anyway
 * @date 2024-02-20
 */
@Slf4j
@Service
public class PersonServiceImpl implements PersonService {

    @Autowired
    private PersonMapper personMapper;

    @Override
    public List<Person> findAll() {
        return personMapper.findAll();
    }

    @Override
    public List<Person> findByCondition(Map<String, Object> map) {
        return personMapper.findByCondition(map);
    }

    @Override
    public List<Person> findPage(PageQuery<Map<String, Object>> pageQuery) {
        PageUtils.startPage(pageQuery);
        List<Person> personList = personMapper.findByCondition(pageQuery.getTerms());
        PageUtils.setPageTotal(personList, pageQuery);
        return personList;
    }

    @Override
    public boolean add(Person person) {
        int c = personMapper.add(person);
        this.updateMate(person);
        return c > 0;
    }

    @Override
    public boolean update(Person person) {
        this.updateMate(person);
        return personMapper.update(person) > 0;
    }

    @Override
    public Person findById(Long id) {
        return personMapper.findById(id);
    }

    @Override
    public int delete(Long id) {
        int c = personMapper.deleteByIds(Arrays.asList(id));
        if (c < 1) {
            return c;
        }
        //更新相关人员的配偶、父母
        personMapper.updateNullMate(id);
        personMapper.updateNullMother(id);
        personMapper.updateNullFather(id);
        return c;
    }

    /**
     * 更新配偶人员
     *
     * @param person
     */
    private void updateMate(Person person) {
        if(person.getMateId() != null) {
            Person matePerson = this.findById(person.getMateId());
            if (matePerson != null) {
                if(matePerson.getMateId() == null) {
                    matePerson.setMateId(person.getId());
                    personMapper.update(matePerson);
                } else if (!person.getMateId().equals(matePerson.getMateId())) {
                    log.error("该配偶存在其他配偶");
                } else {
                    //
                }
            }
        }
    }
}
