<%@ page contentType="text/html;charset=UTF-8" language="java" %>
<%@ taglib uri="http://java.sun.com/jsp/jstl/core" prefix="c"%>
<%@ taglib uri="http://java.sun.com/jsp/jstl/fmt" prefix="fmt"%>
<html>
<head>
    <title>人员列表</title>
    <meta name="renderer" content="webkit">
    <meta http-equiv="X-UA-Compatible" content="IE=edge,chrome=1">
    <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
    <link rel="stylesheet" href="${pageContext.request.contextPath}/asserts/layui/css/layui.css">
</head>
<body>

<%-- 人员列表 --%>
<div style="margin: 0 auto; width: 90%;">
    <form class="layui-form" action="">
        <div class="layui-inline">
            <label class="layui-form-label">姓名</label>
            <div class="layui-input-inline">
                <input type="text" id="name" name="name" autocomplete="off" class="layui-input">
            </div>
        </div>
        <div class="layui-inline">
            <label class="layui-form-label">家庭成员</label>
            <div class="layui-input-inline">
                <select id="familyPersonId" name="familyPersonId" lay-verify="" lay-search>
                    <option value="">请选择</option>
                    <c:forEach items="${familyPersonList}" var="p">
                        <option value="${p.id}">${p.callName}（${p.name}）</option>
                    </c:forEach>
                </select>
            </div>
        </div>
        <div class="layui-inline">
            <label class="layui-form-label">地址</label>
            <div class="layui-input-inline">
                <input id="address" type="text" name="address" autocomplete="off" class="layui-input">
            </div>
        </div>
        <div class="layui-inline">
            <div class="layui-input-inline">
                <button class="layui-btn" id="searchBtn" data-type="reload" style="margin-left: 15px">
                    <i class="layui-icon layui-icon-search"></i> 查询
                </button>
                <button type="reset" class="layui-btn layui-btn-primary">重置</button>
            </div>
        </div>
    </form>

    <table id="personTab" class="layui-hide" lay-filter="person"></table>
</div>

<%-- 表格上方按钮 --%>
<script type="text/html" id="toolbarDemo">
    <div class="layui-btn-container">
        <button class="layui-btn layui-btn-sm" lay-event="addPerson">添加人员</button>
        <button class="layui-btn layui-btn-sm" lay-event="addFavor">添加人情</button>
    </div>
</script>

<%-- 表格行操作栏 --%>
<script type="text/html" id="barDemo">
    <a class="layui-btn layui-btn-primary layui-btn-xs" lay-event="addFavor">添加人情</a>
    <a class="layui-btn layui-btn-xs" lay-event="edit">编辑</a>
    <a class="layui-btn layui-btn-danger layui-btn-xs" lay-event="del">删除</a>
</script>

<script type="text/javascript" src="${pageContext.request.contextPath}/asserts/js/jquery-3.7.1.min.js"></script>
<script type="text/javascript" src="${pageContext.request.contextPath}/asserts/layui/layui.js" charset="utf-8"></script>
<script>
    let headUrl = "${pageContext.request.contextPath}";
    /** 性别格式化 */
    function genderFormat(obj) {
        return obj.gender === 'M' ? '男' : '女';
    }
    /** 婚姻状况格式化 */
    function maritalStatusFormat(obj) {
        return obj.maritalStatus === 1 ? '已婚' : '未婚';
    }
    /** 称呼格式化 */
    function callNameFormat(obj) {
        if(obj.deathDate !== undefined && obj.deathDate !== null) {
            return "<span style='background-color: gray; color: #fff;'>"+obj.callName+"</span>";
        }
        return obj.callName;
    }

    layui.use('table', function () {
        let table = layui.table;
        //数据表格渲染
        table.render({
            id: 'personTab',
            elem: '#personTab',
            toolbar: '#toolbarDemo', //开启头部工具栏，并为其绑定左侧模板
            url: '${pageContext.request.contextPath}/person/listPage',
            method: 'post',
            contentType: "application/json;charset=UTF-8",
            dataType: "json",
            request: {
                pageName: 'pageNo', //页码的参数名称，默认：page
                limitName: 'pageSize' //每页数据量的参数名，默认：limit
            },
            where: {
                terms: {},
                sortName: "p.create_time",
                sortOrder: "asc"
            },
            //开启分页并解析数据
            parseData: function(res) {
                res.count = res.page.total;
                return res;
            },
            page: true,
            limit: 20,
            cellMinWidth: 50, //全局定义常规单元格的最小宽度，layui 2.2.1 新增
            cols: [[
                { type: 'checkbox', field: 'id' },
                { field: 'callName', title: '称呼', width: 80, templet: callNameFormat },
                { field: 'name', title: '姓名', event:'clickName',style:'cursor: pointer;', width: 80 },
                { field: 'mateId', title: '配偶ID', hide:true },
                { field: 'mateName', title: '配偶', event:'clickMate',style:'cursor: pointer;' },
                { field: 'motherId', title: '母亲ID', hide:true },
                { field: 'motherName', title: '母亲', event:'clickMother',style:'cursor: pointer;' },
                { field: 'fatherId', title: '父亲ID', hide:true },
                { field: 'fatherName', title: '父亲', event:'clickFather',style:'cursor: pointer;' },
                { field: 'sort', title: '家中排行', width: 90 },
                { field: 'address', title: '地址', event:'clickAddress',style:'cursor: pointer;' },
                { field: 'gender', title: '性别', width: 80, sort: true, templet: genderFormat},
                { field: 'maritalStatus', title: '婚姻状况', width: 110, sort: true, templet: maritalStatusFormat },
                { field: 'birthday', title: '生日', width: 110 },
                { fixed: 'right', align:'center', width: 240, toolbar: '#barDemo'}
            ]]
        });
        //搜索
        $('#searchBtn').on('click', function () {
            table.reload('personTab', {
                url: '${pageContext.request.contextPath}/person/listPage',
                method: 'post',
                contentType: "application/json;charset=UTF-8",
                dataType: "json",
                request: {
                    pageName: 'pageNo', //页码的参数名称，默认：page
                    limitName: 'pageSize' //每页数据量的参数名，默认：limit
                },
                page: {
                    pageNo: 1 //重新从第 1 页开始
                },
                where : {
                    terms: {
                        name: $("#name").val(),
                        address: $("#address").val(),
                        familyPersonId: $("#familyPersonId").val()
                    },
                    sortName: "p.create_time",
                    sortOrder: "asc"
                }
            });
            return false;
        });

        //头工具栏事件
        table.on('toolbar(person)', function (obj) {
            var checkStatus = table.checkStatus(obj.config.id);
            switch (obj.event) {
                case 'addPerson':
                    //通过这种方式弹出的层，每当它被选择，就会置顶。
                    layer.open({
                        type: 2,
                        title: '新增人员',
                        shade: false,
                        area: ['700px', '600px'],
                        maxmin: true,
                        content: headUrl + "/person/toAdd",
                        zIndex: layer.zIndex, //重点1
                        success: function(layero){
                            layer.setTop(layero); //重点2
                        }
                    });
                    break;
                case 'addFavor':
                    let data = checkStatus.data;
                    let personIds = [];
                    for(let i=0; i<data.length; i++) {
                        personIds.push(data[i].id);
                    }
                    console.log("选中的ID：" + personIds);
                    window.location.href = "${pageContext.request.contextPath}/favor/toAdd?sourcePersonIds=" + personIds.toString();
                    break;
                case 'isAll':
                    layer.msg(checkStatus.isAll ? '全选' : '未全选');
                    break;

                //自定义头工具栏右侧图标 - 提示
                case 'LAYTABLE_TIPS':
                    layer.alert('这是工具栏右侧自定义的一个图标按钮');
                    break;
            };
        });

        //监听行工具事件
        table.on('tool(person)', function (obj) {
            let data = obj.data;
            console.log("点击行数据：" + data);
            if (obj.event === 'clickAddress') {
                $("#address").val(data.address);
                $("#searchBtn").click();
            } else if (obj.event === 'addFavor') {
                $("#address").val(data.address);
                $("#searchBtn").click();
            } else if (obj.event === 'del') {
                //eg1
                layer.confirm('确定要删除？<br/><i>会删掉相关人员的配偶、父母等</i>', {icon: 3, title:'提示'}, function(index){
                    let url = "${pageContext.request.contextPath}/person/del/" + data.id;
                    $.ajax({
                        url:url,
                        type:"POST",
                        contentType:"application/json; charset=utf-8",
                        dataType:"json",
                        success: function(res){
                            console.log(res);
                            if (res.code === 1) {
                                layer.msg(res.msg, {icon: 2});
                            } else {
                                //先给成功提示，然后刷新列表
                                layer.msg('删除成功', {icon: 1, time: 1000}, function() {
                                    layui.table.reload("personTab");
                                });
                            }
                        }
                    })
                    layer.close(index);
                });

            } else if (obj.event === 'edit') {
                //通过这种方式弹出的层，每当它被选择，就会置顶。
                layer.open({
                    type: 2,
                    title: '编辑人员',
                    shade: false,
                    area: ['700px', '600px'],
                    maxmin: true,
                    content: headUrl + "/person/edit/" + data.id,
                    zIndex: layer.zIndex, //重点1
                    success: function(layero){
                        layer.setTop(layero); //重点2
                    }
                });
            } else {
                //点击名字、配偶、母亲、父亲
                if (obj.event === 'clickName') {
                    $("#familyPersonId").val(data.id);
                } else if (obj.event === 'clickMate') {
                    $("#familyPersonId").val(data.mateId);
                } else if (obj.event === 'clickMother') {
                    $("#familyPersonId").val(data.motherId);
                } else if (obj.event === 'clickFather') {
                    $("#familyPersonId").val(data.fatherId);
                }
                layui.form.render();
                $("#searchBtn").click();
            }


        });

    });
</script>
</body>
</html>